spoon.routing.NodeUnreachable

Package spoon :: Package routing :: Class NodeUnreachable |
[hide private]
[frames] | no frames]

# Class NodeUnreachable

source code

    exceptions.Exception --+
                           |
        RoutingProtocolError --+
                               |
                              NodeUnreachable

Raised when trying to send to a node that is not currently reachable. This is not necessarily a permanent condition. Particularly if a transport has just been lost, a node may become available again within a few seconds as a new route is found.

Instance Methods | [hide private]
`` | __init__(self, data, nodeId=None)
Inherited from `exceptions.Exception`: `__getitem__`, `__str__`

Method Details | [hide private]

### __init__(self, data, nodeId=None) (Constructor) | source code
None Overrides: exceptions.Exception.__init__